import "dart:html";

class DaySection
{  
  DaySection(this._color, this._timeStart, this._timeEnd);
  
  DivElement spawn(DateTime date)
  {
    _date = date.toIso8601String();
    _date = _date.substring(0, _date.indexOf("T"));
    DateTime timeStartDate = DateTime.parse(_date + " " + _timeStart);            
    DateTime timeEndDate = DateTime.parse(_date + " " + _timeEnd);
     
    int minutes = timeEndDate.difference(timeStartDate).inMinutes;
    int sectionTop = (0.5 * (timeStartDate.difference(DateTime.parse(_date + " 00:00")).inMinutes - 360)).round();
    int sectionHeight = (0.5 * minutes).round();
     
    _element = new DivElement();
    _element.style.position = "absolute";
    _element.style.top = sectionTop.toString() + "px";
    _element.style.width = "100%";
    _element.style.display = "block";
    _element.style.backgroundColor = _color;
    _element.style.opacity = "0.3";
    _element.style.height = sectionHeight.toString() + "px";
    _element.style.borderTop = _element.style.borderBottom = "1px solid black";
    
    _element.dataset["time_start"] = _timeStart;
    _element.dataset["time_end"] = _timeEnd;
    return _element;
  }
  
  DivElement get element => _element;
  
  String _color;
  String _timeStart;
  String _timeEnd;
  String _date;
  DivElement _element;
}

class Day
{
  Day(this._date)
  {
    _content = new DivElement();
  }
  
  void clear()
  {
    _content.children.clear();    
  }
  
  void setContent(String title, List<DaySection> sections)
  {    
    _content.children.clear();   
    if (title == null) throw new ArgumentError.notNull("title");
    if (sections == null) throw new ArgumentError.notNull("sections");    
    
    _title = title;
    _sections = sections;      
    _sections.forEach((DaySection section) => _content.children.add(section.spawn(_date)));      
  }
  
  List<DaySection> get sections => _sections;
  
  final DateTime _date;
  DivElement _content;
  DivElement get content => _content;
  List<DaySection> _sections;
  String _title;
}
